==> basic_ui-0.0.1.tar.gz: lib/src/widgets/basic_calendar.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:intl/intl.dart';
import 'package:table_calendar/table_calendar.dart';
import 'package:provider/provider.dart';

import '../models/basic_theme.dart';
import 'basic_text.dart';

class BasicCalendar extends StatelessWidget {
  const BasicCalendar({
    Key? key,
    this.onDaySelected,
  }) : super(key: key);

  final Function(DateTime selectedDay, DateTime focusedDay)? onDaySelected;

  @override
  Widget build(BuildContext context) {
    final theme = context.watch<ThemeProvider>().theme;

    final selectedDayState = useState(DateTime.now());
    final focusedDayState = useState(DateTime.now());

    return TableCalendar(
      headerStyle: HeaderStyle(
        leftChevronVisible: false,
        rightChevronVisible: false,
        headerPadding: const EdgeInsets.only(
          left: 16.0,
          right: 16.0,
          top: 16.0,
          bottom: 24.0,
        ),
        titleTextStyle: TextStyle(fontSize: 16, color: theme.primaryColor),
      ),
      onDaySelected: (selectedDay, focusedDay) {
        if (onDaySelected != null) {
          onDaySelected!(selectedDay, focusedDay);
        }
        selectedDayState.value = selectedDay;
        focusedDayState.value = focusedDay;
      },
      selectedDayPredicate: (day) {
        return isSameDay(selectedDayState.value, day);
      },
      firstDay: DateTime.utc(DateTime.now().year - 5),
      lastDay: DateTime.utc(DateTime.now().year + 5),
      focusedDay: focusedDayState.value,
      calendarFormat: CalendarFormat.month,
      startingDayOfWeek: StartingDayOfWeek.monday,
      availableCalendarFormats: const {CalendarFormat.month: 'Month'},
      daysOfWeekStyle: DaysOfWeekStyle(
        dowTextFormatter: (date, locale) =>
            DateFormat.E(locale).format(date).substring(0, 2),
        weekdayStyle: TextStyle(color: theme.fontColor),
        weekendStyle: TextStyle(color: theme.fontColor),
      ),
      calendarStyle: CalendarStyle(
        defaultTextStyle: TextStyle(color: theme.fontColor),
        weekendTextStyle: TextStyle(color: theme.fontColor),
        outsideTextStyle: TextStyle(
          color: theme.fontSubtitleColor.withOpacity(.5),
        ),
      ),
      calendarBuilders: CalendarBuilders(
        todayBuilder: (context, date, _) => _Today(
          date: date,
          theme: theme,
        ),
        selectedBuilder: (context, date, _) => _SelectedDay(
          date: date,
          theme: theme,
        ),
      ),
    );
  }
}

class _SelectedDay extends StatelessWidget {
  const _SelectedDay({
    Key? key,
    required this.date,
    required this.theme,
  }) : super(key: key);

  final DateTime date;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(border: Border.all(color: theme.primaryColor)),
      margin: const EdgeInsets.all(2),
      child: Center(
        child: BasicText(
          "${date.day}",
          color: theme.primaryColor,
          variant: BasicTextVariant.small,
        ),
      ),
    );
  }
}

class _Today extends StatelessWidget {
  const _Today({
    Key? key,
    required this.date,
    required this.theme,
  }) : super(key: key);

  final DateTime date;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return Container(
      color: theme.primaryColor,
      margin: const EdgeInsets.all(2),
      child: Center(
        child: BasicText(
          "${date.day}",
          color: Colors.white,
          variant: BasicTextVariant.small,
        ),
      ),
    );
  }
}

==> basic_ui-0.2.2.tar.gz: lib/src/widgets/basic_calendar.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:intl/intl.dart';
import 'package:table_calendar/table_calendar.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

import '../models/basic_theme.dart';
import 'basic_text.dart';

/// The calendar control lets people select and view a single date their calendar.
class BasicCalendar extends HookWidget {
  const BasicCalendar({
    Key? key,
    this.onDaySelected,
  }) : super(key: key);

  /// The callback when day in calender selected.
  final Function(DateTime selectedDay, DateTime focusedDay)? onDaySelected;

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    final selectedDayState = useState(DateTime.now());
    final focusedDayState = useState(DateTime.now());

    return TableCalendar(
      headerStyle: HeaderStyle(
        leftChevronVisible: false,
        rightChevronVisible: false,
        headerPadding: const EdgeInsets.only(
          left: 16.0,
          right: 16.0,
          top: 16.0,
          bottom: 24.0,
        ),
        titleTextStyle: TextStyle(fontSize: 16, color: theme.primaryColor),
      ),
      onDaySelected: (selectedDay, focusedDay) {
        if (onDaySelected != null) {
          onDaySelected!(selectedDay, focusedDay);
        }
        selectedDayState.value = selectedDay;
        focusedDayState.value = focusedDay;
      },
      selectedDayPredicate: (day) {
        return isSameDay(selectedDayState.value, day);
      },
      firstDay: DateTime.utc(DateTime.now().year - 5),
      lastDay: DateTime.utc(DateTime.now().year + 5),
      focusedDay: focusedDayState.value,
      calendarFormat: CalendarFormat.month,
      startingDayOfWeek: StartingDayOfWeek.monday,
      availableCalendarFormats: const {CalendarFormat.month: 'Month'},
      daysOfWeekStyle: DaysOfWeekStyle(
        dowTextFormatter: (date, locale) =>
            DateFormat.E(locale).format(date).substring(0, 2),
        weekdayStyle: TextStyle(color: theme.fontColor),
        weekendStyle: TextStyle(color: theme.fontColor),
      ),
      calendarStyle: CalendarStyle(
        defaultTextStyle: TextStyle(color: theme.fontColor),
        weekendTextStyle: TextStyle(color: theme.fontColor),
        outsideTextStyle: TextStyle(
          color: theme.fontSubtitleColor.withOpacity(.5),
        ),
      ),
      calendarBuilders: CalendarBuilders(
        todayBuilder: (context, date, _) => _Today(
          date: date,
          theme: theme,
        ),
        selectedBuilder: (context, date, _) => _SelectedDay(
          date: date,
          theme: theme,
        ),
      ),
    );
  }
}

class _SelectedDay extends StatelessWidget {
  const _SelectedDay({
    Key? key,
    required this.date,
    required this.theme,
  }) : super(key: key);

  final DateTime date;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(border: Border.all(color: theme.primaryColor)),
      margin: const EdgeInsets.all(2),
      child: Center(
        child: BasicText(
          "${date.day}",
          color: theme.primaryColor,
          variant: BasicTextVariant.small,
        ),
      ),
    );
  }
}

class _Today extends StatelessWidget {
  const _Today({
    Key? key,
    required this.date,
    required this.theme,
  }) : super(key: key);

  final DateTime date;
  final BasicTheme theme;

  @override
  Widget build(BuildContext context) {
    return Container(
      color: theme.primaryColor,
      margin: const EdgeInsets.all(2),
      child: Center(
        child: BasicText(
          "${date.day}",
          color: Colors.white,
          variant: BasicTextVariant.small,
        ),
      ),
    );
  }
}
